ReferrerPolicy

Enum ReferrerPolicy 

pub enum ReferrerPolicy {
    NoReferrer,
    NoReferrerWhenDowngrade,
    Origin,
    OriginWhenCrossOrigin,
    SameOrigin,
    StrictOrigin,
    StrictOriginWhenCrossOrigin,
    UnsafeUrl,
}
Referrer-Policy header value.

Examples

use http_security_headers::ReferrerPolicy;

let policy = ReferrerPolicy::NoReferrer;
let policy = ReferrerPolicy::StrictOriginWhenCrossOrigin;

Variants



NoReferrer

No referrer information is sent.



NoReferrerWhenDowngrade

Only send the origin when the protocol security level stays the same (HTTPS→HTTPS).



Origin

Only send the origin, not the full URL.



OriginWhenCrossOrigin

Send the full URL when performing a same-origin request, but only the origin for other cases.



SameOrigin

Send the full URL for same-origin requests, and no referrer for cross-origin requests.



StrictOrigin

Only send the origin when the protocol security level stays the same (HTTPS→HTTPS), and send no referrer to a less secure destination (HTTPS→HTTP).



StrictOriginWhenCrossOrigin

Send the full URL for same-origin requests, only the origin for cross-origin requests on the same protocol level, and no referrer to less secure destinations.



UnsafeUrl

Send the full URL for all requests.

Implementations

Source

impl ReferrerPolicy

pub fn as_str(&self) -> &'static str

Converts the policy to its header value string.